client-gok8s.io/client-go/informers/autoscaling Index | Files | Directories

package autoscaling

import "k8s.io/client-go/informers/autoscaling"

Index

Types

type Interface

type Interface interface {
	// V1 provides access to shared informers for resources in V1.
	V1() v1.Interface
	// V2 provides access to shared informers for resources in V2.
	V2() v2.Interface
}

Interface provides access to each of this group's versions.

func New

New returns a new Interface.

Source Files

interface.go

Directories

PathSynopsis
informers/autoscaling/v1
informers/autoscaling/v2
Version
v0.37.0-alpha.0
Published
Apr 9, 2026
Platform
linux/amd64
Imports
3 packages
Last checked
2 hours ago

Tools for package owners.