v1beta1

package
v0.37.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2026 License: Apache-2.0 Imports: 11 Imported by: 149

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCronJobInformer

func NewCronJobInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewCronJobInformer constructs a new informer for CronJob type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedCronJobInformer).

func NewCronJobInformerWithOptions added in v0.36.0

func NewCronJobInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewCronJobInformerWithOptions constructs a new informer for CronJob type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedCronJobInformerWithOptions).

func NewFilteredCronJobInformer

func NewFilteredCronJobInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredCronJobInformer constructs a new informer for CronJob type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedFilteredCronJobInformer).

Types

type CronJobDetailedHandlerFuncs added in v0.37.0

CronJobDetailedHandlerFuncs is a specialization of cache.TypedResourceEventHandlerDetailedFuncs for CronJob.

type CronJobFilteringHandler added in v0.37.0

CronJobFilteringHandler is a specialization of cache.TypedFilteringResourceEventHandler for CronJob.

type CronJobHandlerFuncs added in v0.37.0

CronJobHandlerFuncs is a specialization of cache.TypedResourceEventHandlerFuncs for CronJob.

type CronJobIndexInformer added in v0.37.0

CronJobIndexInformer is a wrapper around the underlying cache.SharedIndexInformer with type-safe variants of several methods.

func NewTypedCronJobInformer added in v0.37.0

func NewTypedCronJobInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers CronJobIndexers) CronJobIndexInformer

NewTypedCronJobInformer constructs a new informer for CronJob type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedCronJobInformerWithOptions added in v0.37.0

func NewTypedCronJobInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) CronJobIndexInformer

NewTypedCronJobInformerWithOptions constructs a new informer for CronJob type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedFilteredCronJobInformer added in v0.37.0

func NewTypedFilteredCronJobInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers CronJobIndexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) CronJobIndexInformer

NewTypedFilteredCronJobInformer constructs a new informer for CronJob type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func ToCronJobIndexInformer added in v0.37.0

func ToCronJobIndexInformer(informer cache.SharedIndexInformer) CronJobIndexInformer

ToCronJobIndexInformer converts an untyped informer into a CronJobIndexInformer.

WARNING: this conversion is only safe if the informer handles objects of type *CronJob. If that is not the case, calling type-safe methods of the returned CronJobIndexInformer leads to runtime panics. A safer alternative is to pass around a CronJobIndexInformer instances that was obtained from a SharedInformerFactory.

type CronJobIndexers added in v0.37.0

type CronJobIndexers = cache.TypedIndexers[*apibatchv1beta1.CronJob]

CronJobIndexers is a specialization of cache.TypedIndexers for CronJob.

type CronJobInformer

type CronJobInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() batchv1beta1.CronJobLister
}

CronJobInformer provides access to a shared informer and lister for CronJobs. Prefer using the type-safe variant (see TypedCronJobInformer).

type DeletedCronJob added in v0.37.0

type DeletedCronJob = cache.DeletedObject[*apibatchv1beta1.CronJob]

DeletedCronJob is a specialization of cache.DeletedObject for CronJob.

type Interface

type Interface interface {
	// CronJobs returns a CronJobInformer.
	CronJobs() TypedCronJobInformer
}

Interface provides access to all the informers in this group version.

func New

New returns a new Interface.

type TypedCronJobInformer added in v0.37.0

type TypedCronJobInformer interface {
	Informer() cache.SharedIndexInformer
	TypedInformer() CronJobIndexInformer
	Lister() batchv1beta1.CronJobLister
}

TypedCronJobInformer provides access to a shared informer and lister for CronJobs, including the type-safe TypedInformer variant. It is a superset of CronJobInformer.

func ToTypedCronJobInformer added in v0.37.0

func ToTypedCronJobInformer(informer CronJobInformer) TypedCronJobInformer

ToTypedCronJobInformer converts an untyped informer into a TypedCronJobInformer.

WARNING: this conversion is only safe if the informer handles objects of type *CronJob. If that is not the case, calling type-safe methods of the returned TypedCronJobInformer leads to runtime panics. A safer alternative is to pass around a TypedCronJobInformer instances that was obtained from a SharedInformerFactory.

Jump to