package v1beta1

import "k8s.io/client-go/informers/certificates/v1beta1"

Index

Functions

func NewCertificateSigningRequestInformer

func NewCertificateSigningRequestInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewCertificateSigningRequestInformer constructs a new informer for CertificateSigningRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewCertificateSigningRequestInformerWithOptions

func NewCertificateSigningRequestInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewCertificateSigningRequestInformerWithOptions constructs a new informer for CertificateSigningRequest type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewClusterTrustBundleInformer

func NewClusterTrustBundleInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewClusterTrustBundleInformer constructs a new informer for ClusterTrustBundle type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewClusterTrustBundleInformerWithOptions

func NewClusterTrustBundleInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewClusterTrustBundleInformerWithOptions constructs a new informer for ClusterTrustBundle type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredCertificateSigningRequestInformer

func NewFilteredCertificateSigningRequestInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredCertificateSigningRequestInformer constructs a new informer for CertificateSigningRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredClusterTrustBundleInformer

func NewFilteredClusterTrustBundleInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredClusterTrustBundleInformer constructs a new informer for ClusterTrustBundle type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredPodCertificateRequestInformer

func NewFilteredPodCertificateRequestInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredPodCertificateRequestInformer constructs a new informer for PodCertificateRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewPodCertificateRequestInformer

func NewPodCertificateRequestInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewPodCertificateRequestInformer constructs a new informer for PodCertificateRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewPodCertificateRequestInformerWithOptions

func NewPodCertificateRequestInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewPodCertificateRequestInformerWithOptions constructs a new informer for PodCertificateRequest type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

Types

type CertificateSigningRequestInformer

type CertificateSigningRequestInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() certificatesv1beta1.CertificateSigningRequestLister
}

CertificateSigningRequestInformer provides access to a shared informer and lister for CertificateSigningRequests.

type ClusterTrustBundleInformer

type ClusterTrustBundleInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() certificatesv1beta1.ClusterTrustBundleLister
}

ClusterTrustBundleInformer provides access to a shared informer and lister for ClusterTrustBundles.

type Interface

type Interface interface {
	// CertificateSigningRequests returns a CertificateSigningRequestInformer.
	CertificateSigningRequests() CertificateSigningRequestInformer
	// ClusterTrustBundles returns a ClusterTrustBundleInformer.
	ClusterTrustBundles() ClusterTrustBundleInformer
	// PodCertificateRequests returns a PodCertificateRequestInformer.
	PodCertificateRequests() PodCertificateRequestInformer
}

Interface provides access to all the informers in this group version.

func New

New returns a new Interface.

type PodCertificateRequestInformer

type PodCertificateRequestInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() certificatesv1beta1.PodCertificateRequestLister
}

PodCertificateRequestInformer provides access to a shared informer and lister for PodCertificateRequests.

Source Files

certificatesigningrequest.go clustertrustbundle.go interface.go podcertificaterequest.go

Version
v0.36.0 (latest)
Published
Apr 22, 2026
Platform
linux/amd64
Imports
11 packages
Last checked
2 minutes ago

Tools for package owners.