package internalinterfaces
import "k8s.io/client-go/informers/internalinterfaces"
Index ¶
Types ¶
type InformerOptions ¶
type InformerOptions struct {
// ResyncPeriod is the resync period for this informer.
// If not set, defaults to 0 (no resync).
ResyncPeriod time.Duration
// Indexers are the indexers for this informer.
Indexers cache.Indexers
// InformerName is used to uniquely identify this informer for metrics.
// If not set, metrics will not be published for this informer.
// Use cache.NewInformerName() to create an InformerName at startup.
InformerName *cache.InformerName
// TweakListOptions is an optional function to modify the list options.
TweakListOptions TweakListOptionsFunc
}
InformerOptions holds the options for creating an informer.
type NewInformerFunc ¶
type NewInformerFunc func(kubernetes.Interface, time.Duration) cache.SharedIndexInformer
NewInformerFunc takes kubernetes.Interface and time.Duration to return a SharedIndexInformer.
type SharedInformerFactory ¶
type SharedInformerFactory interface {
(stopCh <-chan struct{})
(obj runtime.Object, newFunc NewInformerFunc) cache.SharedIndexInformer
() *cache.InformerName
}
SharedInformerFactory a small interface to allow for adding an informer without an import cycle
type TweakListOptionsFunc ¶
type TweakListOptionsFunc func(*v1.ListOptions)
TweakListOptionsFunc is a function that transforms a v1.ListOptions.
Source Files ¶
factory_interfaces.go
- Version
- v0.36.0-rc.1
- Published
- Apr 15, 2026
- Platform
- linux/amd64
- Imports
- 5 packages
- Last checked
- 1 hour ago –
Tools for package owners.