v1alpha1

package
v0.36.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 23, 2026 License: Apache-2.0 Imports: 11 Imported by: 172

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewClusterRoleBindingInformer

func NewClusterRoleBindingInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewClusterRoleBindingInformer constructs a new informer for ClusterRoleBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewClusterRoleBindingInformerWithOptions added in v0.36.0

func NewClusterRoleBindingInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewClusterRoleBindingInformerWithOptions constructs a new informer for ClusterRoleBinding type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewClusterRoleInformer

func NewClusterRoleInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewClusterRoleInformer constructs a new informer for ClusterRole type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewClusterRoleInformerWithOptions added in v0.36.0

func NewClusterRoleInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewClusterRoleInformerWithOptions constructs a new informer for ClusterRole type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredClusterRoleBindingInformer

func NewFilteredClusterRoleBindingInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredClusterRoleBindingInformer constructs a new informer for ClusterRoleBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredClusterRoleInformer

func NewFilteredClusterRoleInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredClusterRoleInformer constructs a new informer for ClusterRole type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredRoleBindingInformer

func NewFilteredRoleBindingInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredRoleBindingInformer constructs a new informer for RoleBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredRoleInformer

func NewFilteredRoleInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredRoleInformer constructs a new informer for Role type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewRoleBindingInformer

func NewRoleBindingInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewRoleBindingInformer constructs a new informer for RoleBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewRoleBindingInformerWithOptions added in v0.36.0

func NewRoleBindingInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewRoleBindingInformerWithOptions constructs a new informer for RoleBinding type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewRoleInformer

func NewRoleInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewRoleInformer constructs a new informer for Role type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewRoleInformerWithOptions added in v0.36.0

func NewRoleInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewRoleInformerWithOptions constructs a new informer for Role type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

Types

type ClusterRoleBindingInformer

type ClusterRoleBindingInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() rbacv1alpha1.ClusterRoleBindingLister
}

ClusterRoleBindingInformer provides access to a shared informer and lister for ClusterRoleBindings.

type ClusterRoleInformer

type ClusterRoleInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() rbacv1alpha1.ClusterRoleLister
}

ClusterRoleInformer provides access to a shared informer and lister for ClusterRoles.

type Interface

type Interface interface {
	// ClusterRoles returns a ClusterRoleInformer.
	ClusterRoles() ClusterRoleInformer
	// ClusterRoleBindings returns a ClusterRoleBindingInformer.
	ClusterRoleBindings() ClusterRoleBindingInformer
	// Roles returns a RoleInformer.
	Roles() RoleInformer
	// RoleBindings returns a RoleBindingInformer.
	RoleBindings() RoleBindingInformer
}

Interface provides access to all the informers in this group version.

func New

New returns a new Interface.

type RoleBindingInformer

type RoleBindingInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() rbacv1alpha1.RoleBindingLister
}

RoleBindingInformer provides access to a shared informer and lister for RoleBindings.

type RoleInformer

type RoleInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() rbacv1alpha1.RoleLister
}

RoleInformer provides access to a shared informer and lister for Roles.

Jump to