v1beta1

package
v0.37.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2026 License: Apache-2.0 Imports: 11 Imported by: 180

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewClusterRoleBindingInformer

func NewClusterRoleBindingInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewClusterRoleBindingInformer constructs a new informer for ClusterRoleBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedClusterRoleBindingInformer).

func NewClusterRoleBindingInformerWithOptions added in v0.36.0

func NewClusterRoleBindingInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewClusterRoleBindingInformerWithOptions constructs a new informer for ClusterRoleBinding type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedClusterRoleBindingInformerWithOptions).

func NewClusterRoleInformer

func NewClusterRoleInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewClusterRoleInformer constructs a new informer for ClusterRole type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedClusterRoleInformer).

func NewClusterRoleInformerWithOptions added in v0.36.0

func NewClusterRoleInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewClusterRoleInformerWithOptions constructs a new informer for ClusterRole type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedClusterRoleInformerWithOptions).

func NewFilteredClusterRoleBindingInformer

func NewFilteredClusterRoleBindingInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredClusterRoleBindingInformer constructs a new informer for ClusterRoleBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedFilteredClusterRoleBindingInformer).

func NewFilteredClusterRoleInformer

func NewFilteredClusterRoleInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredClusterRoleInformer constructs a new informer for ClusterRole type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedFilteredClusterRoleInformer).

func NewFilteredRoleBindingInformer

func NewFilteredRoleBindingInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredRoleBindingInformer constructs a new informer for RoleBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedFilteredRoleBindingInformer).

func NewFilteredRoleInformer

func NewFilteredRoleInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredRoleInformer constructs a new informer for Role type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedFilteredRoleInformer).

func NewRoleBindingInformer

func NewRoleBindingInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewRoleBindingInformer constructs a new informer for RoleBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedRoleBindingInformer).

func NewRoleBindingInformerWithOptions added in v0.36.0

func NewRoleBindingInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewRoleBindingInformerWithOptions constructs a new informer for RoleBinding type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedRoleBindingInformerWithOptions).

func NewRoleInformer

func NewRoleInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewRoleInformer constructs a new informer for Role type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedRoleInformer).

func NewRoleInformerWithOptions added in v0.36.0

func NewRoleInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewRoleInformerWithOptions constructs a new informer for Role type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedRoleInformerWithOptions).

Types

type ClusterRoleBindingDetailedHandlerFuncs added in v0.37.0

type ClusterRoleBindingDetailedHandlerFuncs = cache.TypedResourceEventHandlerDetailedFuncs[*apirbacv1beta1.ClusterRoleBinding]

ClusterRoleBindingDetailedHandlerFuncs is a specialization of cache.TypedResourceEventHandlerDetailedFuncs for ClusterRoleBinding.

type ClusterRoleBindingFilteringHandler added in v0.37.0

type ClusterRoleBindingFilteringHandler = cache.TypedFilteringResourceEventHandler[*apirbacv1beta1.ClusterRoleBinding]

ClusterRoleBindingFilteringHandler is a specialization of cache.TypedFilteringResourceEventHandler for ClusterRoleBinding.

type ClusterRoleBindingHandlerFuncs added in v0.37.0

type ClusterRoleBindingHandlerFuncs = cache.TypedResourceEventHandlerFuncs[*apirbacv1beta1.ClusterRoleBinding]

ClusterRoleBindingHandlerFuncs is a specialization of cache.TypedResourceEventHandlerFuncs for ClusterRoleBinding.

type ClusterRoleBindingIndexInformer added in v0.37.0

type ClusterRoleBindingIndexInformer cache.TypedSharedIndexInformer[*apirbacv1beta1.ClusterRoleBinding]

ClusterRoleBindingIndexInformer is a wrapper around the underlying cache.SharedIndexInformer with type-safe variants of several methods.

func NewTypedClusterRoleBindingInformer added in v0.37.0

func NewTypedClusterRoleBindingInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers ClusterRoleBindingIndexers) ClusterRoleBindingIndexInformer

NewTypedClusterRoleBindingInformer constructs a new informer for ClusterRoleBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedClusterRoleBindingInformerWithOptions added in v0.37.0

func NewTypedClusterRoleBindingInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) ClusterRoleBindingIndexInformer

NewTypedClusterRoleBindingInformerWithOptions constructs a new informer for ClusterRoleBinding type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedFilteredClusterRoleBindingInformer added in v0.37.0

func NewTypedFilteredClusterRoleBindingInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers ClusterRoleBindingIndexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) ClusterRoleBindingIndexInformer

NewTypedFilteredClusterRoleBindingInformer constructs a new informer for ClusterRoleBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func ToClusterRoleBindingIndexInformer added in v0.37.0

func ToClusterRoleBindingIndexInformer(informer cache.SharedIndexInformer) ClusterRoleBindingIndexInformer

ToClusterRoleBindingIndexInformer converts an untyped informer into a ClusterRoleBindingIndexInformer.

WARNING: this conversion is only safe if the informer handles objects of type *ClusterRoleBinding. If that is not the case, calling type-safe methods of the returned ClusterRoleBindingIndexInformer leads to runtime panics. A safer alternative is to pass around a ClusterRoleBindingIndexInformer instances that was obtained from a SharedInformerFactory.

type ClusterRoleBindingIndexers added in v0.37.0

type ClusterRoleBindingIndexers = cache.TypedIndexers[*apirbacv1beta1.ClusterRoleBinding]

ClusterRoleBindingIndexers is a specialization of cache.TypedIndexers for ClusterRoleBinding.

type ClusterRoleBindingInformer

type ClusterRoleBindingInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() rbacv1beta1.ClusterRoleBindingLister
}

ClusterRoleBindingInformer provides access to a shared informer and lister for ClusterRoleBindings. Prefer using the type-safe variant (see TypedClusterRoleBindingInformer).

type ClusterRoleDetailedHandlerFuncs added in v0.37.0

type ClusterRoleDetailedHandlerFuncs = cache.TypedResourceEventHandlerDetailedFuncs[*apirbacv1beta1.ClusterRole]

ClusterRoleDetailedHandlerFuncs is a specialization of cache.TypedResourceEventHandlerDetailedFuncs for ClusterRole.

type ClusterRoleFilteringHandler added in v0.37.0

ClusterRoleFilteringHandler is a specialization of cache.TypedFilteringResourceEventHandler for ClusterRole.

type ClusterRoleHandlerFuncs added in v0.37.0

ClusterRoleHandlerFuncs is a specialization of cache.TypedResourceEventHandlerFuncs for ClusterRole.

type ClusterRoleIndexInformer added in v0.37.0

type ClusterRoleIndexInformer cache.TypedSharedIndexInformer[*apirbacv1beta1.ClusterRole]

ClusterRoleIndexInformer is a wrapper around the underlying cache.SharedIndexInformer with type-safe variants of several methods.

func NewTypedClusterRoleInformer added in v0.37.0

func NewTypedClusterRoleInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers ClusterRoleIndexers) ClusterRoleIndexInformer

NewTypedClusterRoleInformer constructs a new informer for ClusterRole type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedClusterRoleInformerWithOptions added in v0.37.0

func NewTypedClusterRoleInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) ClusterRoleIndexInformer

NewTypedClusterRoleInformerWithOptions constructs a new informer for ClusterRole type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedFilteredClusterRoleInformer added in v0.37.0

func NewTypedFilteredClusterRoleInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers ClusterRoleIndexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) ClusterRoleIndexInformer

NewTypedFilteredClusterRoleInformer constructs a new informer for ClusterRole type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func ToClusterRoleIndexInformer added in v0.37.0

func ToClusterRoleIndexInformer(informer cache.SharedIndexInformer) ClusterRoleIndexInformer

ToClusterRoleIndexInformer converts an untyped informer into a ClusterRoleIndexInformer.

WARNING: this conversion is only safe if the informer handles objects of type *ClusterRole. If that is not the case, calling type-safe methods of the returned ClusterRoleIndexInformer leads to runtime panics. A safer alternative is to pass around a ClusterRoleIndexInformer instances that was obtained from a SharedInformerFactory.

type ClusterRoleIndexers added in v0.37.0

type ClusterRoleIndexers = cache.TypedIndexers[*apirbacv1beta1.ClusterRole]

ClusterRoleIndexers is a specialization of cache.TypedIndexers for ClusterRole.

type ClusterRoleInformer

type ClusterRoleInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() rbacv1beta1.ClusterRoleLister
}

ClusterRoleInformer provides access to a shared informer and lister for ClusterRoles. Prefer using the type-safe variant (see TypedClusterRoleInformer).

type DeletedClusterRole added in v0.37.0

type DeletedClusterRole = cache.DeletedObject[*apirbacv1beta1.ClusterRole]

DeletedClusterRole is a specialization of cache.DeletedObject for ClusterRole.

type DeletedClusterRoleBinding added in v0.37.0

type DeletedClusterRoleBinding = cache.DeletedObject[*apirbacv1beta1.ClusterRoleBinding]

DeletedClusterRoleBinding is a specialization of cache.DeletedObject for ClusterRoleBinding.

type DeletedRole added in v0.37.0

type DeletedRole = cache.DeletedObject[*apirbacv1beta1.Role]

DeletedRole is a specialization of cache.DeletedObject for Role.

type DeletedRoleBinding added in v0.37.0

type DeletedRoleBinding = cache.DeletedObject[*apirbacv1beta1.RoleBinding]

DeletedRoleBinding is a specialization of cache.DeletedObject for RoleBinding.

type Interface

type Interface interface {
	// ClusterRoles returns a ClusterRoleInformer.
	ClusterRoles() TypedClusterRoleInformer
	// ClusterRoleBindings returns a ClusterRoleBindingInformer.
	ClusterRoleBindings() TypedClusterRoleBindingInformer
	// Roles returns a RoleInformer.
	Roles() TypedRoleInformer
	// RoleBindings returns a RoleBindingInformer.
	RoleBindings() TypedRoleBindingInformer
}

Interface provides access to all the informers in this group version.

func New

New returns a new Interface.

type RoleBindingDetailedHandlerFuncs added in v0.37.0

type RoleBindingDetailedHandlerFuncs = cache.TypedResourceEventHandlerDetailedFuncs[*apirbacv1beta1.RoleBinding]

RoleBindingDetailedHandlerFuncs is a specialization of cache.TypedResourceEventHandlerDetailedFuncs for RoleBinding.

type RoleBindingFilteringHandler added in v0.37.0

RoleBindingFilteringHandler is a specialization of cache.TypedFilteringResourceEventHandler for RoleBinding.

type RoleBindingHandlerFuncs added in v0.37.0

RoleBindingHandlerFuncs is a specialization of cache.TypedResourceEventHandlerFuncs for RoleBinding.

type RoleBindingIndexInformer added in v0.37.0

type RoleBindingIndexInformer cache.TypedSharedIndexInformer[*apirbacv1beta1.RoleBinding]

RoleBindingIndexInformer is a wrapper around the underlying cache.SharedIndexInformer with type-safe variants of several methods.

func NewTypedFilteredRoleBindingInformer added in v0.37.0

func NewTypedFilteredRoleBindingInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers RoleBindingIndexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) RoleBindingIndexInformer

NewTypedFilteredRoleBindingInformer constructs a new informer for RoleBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedRoleBindingInformer added in v0.37.0

func NewTypedRoleBindingInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers RoleBindingIndexers) RoleBindingIndexInformer

NewTypedRoleBindingInformer constructs a new informer for RoleBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedRoleBindingInformerWithOptions added in v0.37.0

func NewTypedRoleBindingInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) RoleBindingIndexInformer

NewTypedRoleBindingInformerWithOptions constructs a new informer for RoleBinding type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func ToRoleBindingIndexInformer added in v0.37.0

func ToRoleBindingIndexInformer(informer cache.SharedIndexInformer) RoleBindingIndexInformer

ToRoleBindingIndexInformer converts an untyped informer into a RoleBindingIndexInformer.

WARNING: this conversion is only safe if the informer handles objects of type *RoleBinding. If that is not the case, calling type-safe methods of the returned RoleBindingIndexInformer leads to runtime panics. A safer alternative is to pass around a RoleBindingIndexInformer instances that was obtained from a SharedInformerFactory.

type RoleBindingIndexers added in v0.37.0

type RoleBindingIndexers = cache.TypedIndexers[*apirbacv1beta1.RoleBinding]

RoleBindingIndexers is a specialization of cache.TypedIndexers for RoleBinding.

type RoleBindingInformer

type RoleBindingInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() rbacv1beta1.RoleBindingLister
}

RoleBindingInformer provides access to a shared informer and lister for RoleBindings. Prefer using the type-safe variant (see TypedRoleBindingInformer).

type RoleDetailedHandlerFuncs added in v0.37.0

RoleDetailedHandlerFuncs is a specialization of cache.TypedResourceEventHandlerDetailedFuncs for Role.

type RoleFilteringHandler added in v0.37.0

RoleFilteringHandler is a specialization of cache.TypedFilteringResourceEventHandler for Role.

type RoleHandlerFuncs added in v0.37.0

RoleHandlerFuncs is a specialization of cache.TypedResourceEventHandlerFuncs for Role.

type RoleIndexInformer added in v0.37.0

RoleIndexInformer is a wrapper around the underlying cache.SharedIndexInformer with type-safe variants of several methods.

func NewTypedFilteredRoleInformer added in v0.37.0

func NewTypedFilteredRoleInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers RoleIndexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) RoleIndexInformer

NewTypedFilteredRoleInformer constructs a new informer for Role type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedRoleInformer added in v0.37.0

func NewTypedRoleInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers RoleIndexers) RoleIndexInformer

NewTypedRoleInformer constructs a new informer for Role type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedRoleInformerWithOptions added in v0.37.0

func NewTypedRoleInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) RoleIndexInformer

NewTypedRoleInformerWithOptions constructs a new informer for Role type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func ToRoleIndexInformer added in v0.37.0

func ToRoleIndexInformer(informer cache.SharedIndexInformer) RoleIndexInformer

ToRoleIndexInformer converts an untyped informer into a RoleIndexInformer.

WARNING: this conversion is only safe if the informer handles objects of type *Role. If that is not the case, calling type-safe methods of the returned RoleIndexInformer leads to runtime panics. A safer alternative is to pass around a RoleIndexInformer instances that was obtained from a SharedInformerFactory.

type RoleIndexers added in v0.37.0

type RoleIndexers = cache.TypedIndexers[*apirbacv1beta1.Role]

RoleIndexers is a specialization of cache.TypedIndexers for Role.

type RoleInformer

type RoleInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() rbacv1beta1.RoleLister
}

RoleInformer provides access to a shared informer and lister for Roles. Prefer using the type-safe variant (see TypedRoleInformer).

type TypedClusterRoleBindingInformer added in v0.37.0

type TypedClusterRoleBindingInformer interface {
	Informer() cache.SharedIndexInformer
	TypedInformer() ClusterRoleBindingIndexInformer
	Lister() rbacv1beta1.ClusterRoleBindingLister
}

TypedClusterRoleBindingInformer provides access to a shared informer and lister for ClusterRoleBindings, including the type-safe TypedInformer variant. It is a superset of ClusterRoleBindingInformer.

func ToTypedClusterRoleBindingInformer added in v0.37.0

func ToTypedClusterRoleBindingInformer(informer ClusterRoleBindingInformer) TypedClusterRoleBindingInformer

ToTypedClusterRoleBindingInformer converts an untyped informer into a TypedClusterRoleBindingInformer.

WARNING: this conversion is only safe if the informer handles objects of type *ClusterRoleBinding. If that is not the case, calling type-safe methods of the returned TypedClusterRoleBindingInformer leads to runtime panics. A safer alternative is to pass around a TypedClusterRoleBindingInformer instances that was obtained from a SharedInformerFactory.

type TypedClusterRoleInformer added in v0.37.0

type TypedClusterRoleInformer interface {
	Informer() cache.SharedIndexInformer
	TypedInformer() ClusterRoleIndexInformer
	Lister() rbacv1beta1.ClusterRoleLister
}

TypedClusterRoleInformer provides access to a shared informer and lister for ClusterRoles, including the type-safe TypedInformer variant. It is a superset of ClusterRoleInformer.

func ToTypedClusterRoleInformer added in v0.37.0

func ToTypedClusterRoleInformer(informer ClusterRoleInformer) TypedClusterRoleInformer

ToTypedClusterRoleInformer converts an untyped informer into a TypedClusterRoleInformer.

WARNING: this conversion is only safe if the informer handles objects of type *ClusterRole. If that is not the case, calling type-safe methods of the returned TypedClusterRoleInformer leads to runtime panics. A safer alternative is to pass around a TypedClusterRoleInformer instances that was obtained from a SharedInformerFactory.

type TypedRoleBindingInformer added in v0.37.0

type TypedRoleBindingInformer interface {
	Informer() cache.SharedIndexInformer
	TypedInformer() RoleBindingIndexInformer
	Lister() rbacv1beta1.RoleBindingLister
}

TypedRoleBindingInformer provides access to a shared informer and lister for RoleBindings, including the type-safe TypedInformer variant. It is a superset of RoleBindingInformer.

func ToTypedRoleBindingInformer added in v0.37.0

func ToTypedRoleBindingInformer(informer RoleBindingInformer) TypedRoleBindingInformer

ToTypedRoleBindingInformer converts an untyped informer into a TypedRoleBindingInformer.

WARNING: this conversion is only safe if the informer handles objects of type *RoleBinding. If that is not the case, calling type-safe methods of the returned TypedRoleBindingInformer leads to runtime panics. A safer alternative is to pass around a TypedRoleBindingInformer instances that was obtained from a SharedInformerFactory.

type TypedRoleInformer added in v0.37.0

type TypedRoleInformer interface {
	Informer() cache.SharedIndexInformer
	TypedInformer() RoleIndexInformer
	Lister() rbacv1beta1.RoleLister
}

TypedRoleInformer provides access to a shared informer and lister for Roles, including the type-safe TypedInformer variant. It is a superset of RoleInformer.

func ToTypedRoleInformer added in v0.37.0

func ToTypedRoleInformer(informer RoleInformer) TypedRoleInformer

ToTypedRoleInformer converts an untyped informer into a TypedRoleInformer.

WARNING: this conversion is only safe if the informer handles objects of type *Role. If that is not the case, calling type-safe methods of the returned TypedRoleInformer leads to runtime panics. A safer alternative is to pass around a TypedRoleInformer instances that was obtained from a SharedInformerFactory.

Jump to