client-gok8s.io/client-go/informers/resource/v1alpha3 Index | Files

package v1alpha3

import "k8s.io/client-go/informers/resource/v1alpha3"

Index

Functions

func NewDeviceTaintRuleInformer

func NewDeviceTaintRuleInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewDeviceTaintRuleInformer constructs a new informer for DeviceTaintRule type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewDeviceTaintRuleInformerWithOptions

func NewDeviceTaintRuleInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewDeviceTaintRuleInformerWithOptions constructs a new informer for DeviceTaintRule type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredDeviceTaintRuleInformer

func NewFilteredDeviceTaintRuleInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredDeviceTaintRuleInformer constructs a new informer for DeviceTaintRule type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredResourcePoolStatusRequestInformer

func NewFilteredResourcePoolStatusRequestInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredResourcePoolStatusRequestInformer constructs a new informer for ResourcePoolStatusRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewResourcePoolStatusRequestInformer

func NewResourcePoolStatusRequestInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewResourcePoolStatusRequestInformer constructs a new informer for ResourcePoolStatusRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewResourcePoolStatusRequestInformerWithOptions

func NewResourcePoolStatusRequestInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewResourcePoolStatusRequestInformerWithOptions constructs a new informer for ResourcePoolStatusRequest type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

Types

type DeviceTaintRuleInformer

type DeviceTaintRuleInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() resourcev1alpha3.DeviceTaintRuleLister
}

DeviceTaintRuleInformer provides access to a shared informer and lister for DeviceTaintRules.

type Interface

type Interface interface {
	// DeviceTaintRules returns a DeviceTaintRuleInformer.
	DeviceTaintRules() DeviceTaintRuleInformer
	// ResourcePoolStatusRequests returns a ResourcePoolStatusRequestInformer.
	ResourcePoolStatusRequests() ResourcePoolStatusRequestInformer
}

Interface provides access to all the informers in this group version.

func New

New returns a new Interface.

type ResourcePoolStatusRequestInformer

type ResourcePoolStatusRequestInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() resourcev1alpha3.ResourcePoolStatusRequestLister
}

ResourcePoolStatusRequestInformer provides access to a shared informer and lister for ResourcePoolStatusRequests.

Source Files

devicetaintrule.go interface.go resourcepoolstatusrequest.go

Version
v0.36.0 (latest)
Published
Apr 22, 2026
Platform
linux/amd64
Imports
11 packages
Last checked
3 minutes ago

Tools for package owners.