client-gok8s.io/client-go/informers/resource/v1beta1 Index | Files

package v1beta1

import "k8s.io/client-go/informers/resource/v1beta1"

Index

Functions

func NewDeviceClassInformer

func NewDeviceClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewDeviceClassInformer constructs a new informer for DeviceClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewDeviceClassInformerWithOptions

func NewDeviceClassInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewDeviceClassInformerWithOptions constructs a new informer for DeviceClass type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredDeviceClassInformer

func NewFilteredDeviceClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredDeviceClassInformer constructs a new informer for DeviceClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredResourceClaimInformer

func NewFilteredResourceClaimInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredResourceClaimInformer constructs a new informer for ResourceClaim type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredResourceClaimTemplateInformer

func NewFilteredResourceClaimTemplateInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredResourceClaimTemplateInformer constructs a new informer for ResourceClaimTemplate type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredResourceSliceInformer

func NewFilteredResourceSliceInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredResourceSliceInformer constructs a new informer for ResourceSlice type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewResourceClaimInformer

func NewResourceClaimInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewResourceClaimInformer constructs a new informer for ResourceClaim type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewResourceClaimInformerWithOptions

func NewResourceClaimInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewResourceClaimInformerWithOptions constructs a new informer for ResourceClaim type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewResourceClaimTemplateInformer

func NewResourceClaimTemplateInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewResourceClaimTemplateInformer constructs a new informer for ResourceClaimTemplate type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewResourceClaimTemplateInformerWithOptions

func NewResourceClaimTemplateInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewResourceClaimTemplateInformerWithOptions constructs a new informer for ResourceClaimTemplate type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewResourceSliceInformer

func NewResourceSliceInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewResourceSliceInformer constructs a new informer for ResourceSlice type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewResourceSliceInformerWithOptions

func NewResourceSliceInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewResourceSliceInformerWithOptions constructs a new informer for ResourceSlice type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

Types

type DeviceClassInformer

type DeviceClassInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() resourcev1beta1.DeviceClassLister
}

DeviceClassInformer provides access to a shared informer and lister for DeviceClasses.

type Interface

type Interface interface {
	// DeviceClasses returns a DeviceClassInformer.
	DeviceClasses() DeviceClassInformer
	// ResourceClaims returns a ResourceClaimInformer.
	ResourceClaims() ResourceClaimInformer
	// ResourceClaimTemplates returns a ResourceClaimTemplateInformer.
	ResourceClaimTemplates() ResourceClaimTemplateInformer
	// ResourceSlices returns a ResourceSliceInformer.
	ResourceSlices() ResourceSliceInformer
}

Interface provides access to all the informers in this group version.

func New

New returns a new Interface.

type ResourceClaimInformer

type ResourceClaimInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() resourcev1beta1.ResourceClaimLister
}

ResourceClaimInformer provides access to a shared informer and lister for ResourceClaims.

type ResourceClaimTemplateInformer

type ResourceClaimTemplateInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() resourcev1beta1.ResourceClaimTemplateLister
}

ResourceClaimTemplateInformer provides access to a shared informer and lister for ResourceClaimTemplates.

type ResourceSliceInformer

type ResourceSliceInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() resourcev1beta1.ResourceSliceLister
}

ResourceSliceInformer provides access to a shared informer and lister for ResourceSlices.

Source Files

deviceclass.go interface.go resourceclaim.go resourceclaimtemplate.go resourceslice.go

Version
v0.37.0-alpha.0
Published
Apr 9, 2026
Platform
linux/amd64
Imports
11 packages
Last checked
5 minutes ago

Tools for package owners.