v1

package
v0.37.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2026 License: Apache-2.0 Imports: 11 Imported by: 387

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCSIDriverInformer added in v0.18.0

func NewCSIDriverInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewCSIDriverInformer constructs a new informer for CSIDriver type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedCSIDriverInformer).

func NewCSIDriverInformerWithOptions added in v0.36.0

func NewCSIDriverInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewCSIDriverInformerWithOptions constructs a new informer for CSIDriver type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedCSIDriverInformerWithOptions).

func NewCSINodeInformer added in v0.17.0

func NewCSINodeInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewCSINodeInformer constructs a new informer for CSINode type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedCSINodeInformer).

func NewCSINodeInformerWithOptions added in v0.36.0

func NewCSINodeInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewCSINodeInformerWithOptions constructs a new informer for CSINode type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedCSINodeInformerWithOptions).

func NewCSIStorageCapacityInformer added in v0.24.0

func NewCSIStorageCapacityInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewCSIStorageCapacityInformer constructs a new informer for CSIStorageCapacity type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedCSIStorageCapacityInformer).

func NewCSIStorageCapacityInformerWithOptions added in v0.36.0

func NewCSIStorageCapacityInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewCSIStorageCapacityInformerWithOptions constructs a new informer for CSIStorageCapacity type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedCSIStorageCapacityInformerWithOptions).

func NewFilteredCSIDriverInformer added in v0.18.0

func NewFilteredCSIDriverInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredCSIDriverInformer constructs a new informer for CSIDriver type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedFilteredCSIDriverInformer).

func NewFilteredCSINodeInformer added in v0.17.0

func NewFilteredCSINodeInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredCSINodeInformer constructs a new informer for CSINode type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedFilteredCSINodeInformer).

func NewFilteredCSIStorageCapacityInformer added in v0.24.0

func NewFilteredCSIStorageCapacityInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredCSIStorageCapacityInformer constructs a new informer for CSIStorageCapacity type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedFilteredCSIStorageCapacityInformer).

func NewFilteredStorageClassInformer

func NewFilteredStorageClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredStorageClassInformer constructs a new informer for StorageClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedFilteredStorageClassInformer).

func NewFilteredVolumeAttachmentInformer

func NewFilteredVolumeAttachmentInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredVolumeAttachmentInformer constructs a new informer for VolumeAttachment type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedFilteredVolumeAttachmentInformer).

func NewFilteredVolumeAttributesClassInformer added in v0.34.0

func NewFilteredVolumeAttributesClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredVolumeAttributesClassInformer constructs a new informer for VolumeAttributesClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedFilteredVolumeAttributesClassInformer).

func NewStorageClassInformer

func NewStorageClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewStorageClassInformer constructs a new informer for StorageClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedStorageClassInformer).

func NewStorageClassInformerWithOptions added in v0.36.0

func NewStorageClassInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewStorageClassInformerWithOptions constructs a new informer for StorageClass type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedStorageClassInformerWithOptions).

func NewVolumeAttachmentInformer

func NewVolumeAttachmentInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewVolumeAttachmentInformer constructs a new informer for VolumeAttachment type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedVolumeAttachmentInformer).

func NewVolumeAttachmentInformerWithOptions added in v0.36.0

func NewVolumeAttachmentInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewVolumeAttachmentInformerWithOptions constructs a new informer for VolumeAttachment type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedVolumeAttachmentInformerWithOptions).

func NewVolumeAttributesClassInformer added in v0.34.0

func NewVolumeAttributesClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewVolumeAttributesClassInformer constructs a new informer for VolumeAttributesClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedVolumeAttributesClassInformer).

func NewVolumeAttributesClassInformerWithOptions added in v0.36.0

func NewVolumeAttributesClassInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) cache.SharedIndexInformer

NewVolumeAttributesClassInformerWithOptions constructs a new informer for VolumeAttributesClass type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server. If you really need an independent one, prefer using the type-safe variant (see NewTypedVolumeAttributesClassInformerWithOptions).

Types

type CSIDriverDetailedHandlerFuncs added in v0.37.0

type CSIDriverDetailedHandlerFuncs = cache.TypedResourceEventHandlerDetailedFuncs[*apistoragev1.CSIDriver]

CSIDriverDetailedHandlerFuncs is a specialization of cache.TypedResourceEventHandlerDetailedFuncs for CSIDriver.

type CSIDriverFilteringHandler added in v0.37.0

type CSIDriverFilteringHandler = cache.TypedFilteringResourceEventHandler[*apistoragev1.CSIDriver]

CSIDriverFilteringHandler is a specialization of cache.TypedFilteringResourceEventHandler for CSIDriver.

type CSIDriverHandlerFuncs added in v0.37.0

CSIDriverHandlerFuncs is a specialization of cache.TypedResourceEventHandlerFuncs for CSIDriver.

type CSIDriverIndexInformer added in v0.37.0

type CSIDriverIndexInformer cache.TypedSharedIndexInformer[*apistoragev1.CSIDriver]

CSIDriverIndexInformer is a wrapper around the underlying cache.SharedIndexInformer with type-safe variants of several methods.

func NewTypedCSIDriverInformer added in v0.37.0

func NewTypedCSIDriverInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers CSIDriverIndexers) CSIDriverIndexInformer

NewTypedCSIDriverInformer constructs a new informer for CSIDriver type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedCSIDriverInformerWithOptions added in v0.37.0

func NewTypedCSIDriverInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) CSIDriverIndexInformer

NewTypedCSIDriverInformerWithOptions constructs a new informer for CSIDriver type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedFilteredCSIDriverInformer added in v0.37.0

func NewTypedFilteredCSIDriverInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers CSIDriverIndexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) CSIDriverIndexInformer

NewTypedFilteredCSIDriverInformer constructs a new informer for CSIDriver type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func ToCSIDriverIndexInformer added in v0.37.0

func ToCSIDriverIndexInformer(informer cache.SharedIndexInformer) CSIDriverIndexInformer

ToCSIDriverIndexInformer converts an untyped informer into a CSIDriverIndexInformer.

WARNING: this conversion is only safe if the informer handles objects of type *CSIDriver. If that is not the case, calling type-safe methods of the returned CSIDriverIndexInformer leads to runtime panics. A safer alternative is to pass around a CSIDriverIndexInformer instances that was obtained from a SharedInformerFactory.

type CSIDriverIndexers added in v0.37.0

type CSIDriverIndexers = cache.TypedIndexers[*apistoragev1.CSIDriver]

CSIDriverIndexers is a specialization of cache.TypedIndexers for CSIDriver.

type CSIDriverInformer added in v0.18.0

type CSIDriverInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() storagev1.CSIDriverLister
}

CSIDriverInformer provides access to a shared informer and lister for CSIDrivers. Prefer using the type-safe variant (see TypedCSIDriverInformer).

type CSINodeDetailedHandlerFuncs added in v0.37.0

type CSINodeDetailedHandlerFuncs = cache.TypedResourceEventHandlerDetailedFuncs[*apistoragev1.CSINode]

CSINodeDetailedHandlerFuncs is a specialization of cache.TypedResourceEventHandlerDetailedFuncs for CSINode.

type CSINodeFilteringHandler added in v0.37.0

CSINodeFilteringHandler is a specialization of cache.TypedFilteringResourceEventHandler for CSINode.

type CSINodeHandlerFuncs added in v0.37.0

CSINodeHandlerFuncs is a specialization of cache.TypedResourceEventHandlerFuncs for CSINode.

type CSINodeIndexInformer added in v0.37.0

type CSINodeIndexInformer cache.TypedSharedIndexInformer[*apistoragev1.CSINode]

CSINodeIndexInformer is a wrapper around the underlying cache.SharedIndexInformer with type-safe variants of several methods.

func NewTypedCSINodeInformer added in v0.37.0

func NewTypedCSINodeInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers CSINodeIndexers) CSINodeIndexInformer

NewTypedCSINodeInformer constructs a new informer for CSINode type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedCSINodeInformerWithOptions added in v0.37.0

func NewTypedCSINodeInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) CSINodeIndexInformer

NewTypedCSINodeInformerWithOptions constructs a new informer for CSINode type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedFilteredCSINodeInformer added in v0.37.0

func NewTypedFilteredCSINodeInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers CSINodeIndexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) CSINodeIndexInformer

NewTypedFilteredCSINodeInformer constructs a new informer for CSINode type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func ToCSINodeIndexInformer added in v0.37.0

func ToCSINodeIndexInformer(informer cache.SharedIndexInformer) CSINodeIndexInformer

ToCSINodeIndexInformer converts an untyped informer into a CSINodeIndexInformer.

WARNING: this conversion is only safe if the informer handles objects of type *CSINode. If that is not the case, calling type-safe methods of the returned CSINodeIndexInformer leads to runtime panics. A safer alternative is to pass around a CSINodeIndexInformer instances that was obtained from a SharedInformerFactory.

type CSINodeIndexers added in v0.37.0

type CSINodeIndexers = cache.TypedIndexers[*apistoragev1.CSINode]

CSINodeIndexers is a specialization of cache.TypedIndexers for CSINode.

type CSINodeInformer added in v0.17.0

type CSINodeInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() storagev1.CSINodeLister
}

CSINodeInformer provides access to a shared informer and lister for CSINodes. Prefer using the type-safe variant (see TypedCSINodeInformer).

type CSIStorageCapacityDetailedHandlerFuncs added in v0.37.0

type CSIStorageCapacityDetailedHandlerFuncs = cache.TypedResourceEventHandlerDetailedFuncs[*apistoragev1.CSIStorageCapacity]

CSIStorageCapacityDetailedHandlerFuncs is a specialization of cache.TypedResourceEventHandlerDetailedFuncs for CSIStorageCapacity.

type CSIStorageCapacityFilteringHandler added in v0.37.0

type CSIStorageCapacityFilteringHandler = cache.TypedFilteringResourceEventHandler[*apistoragev1.CSIStorageCapacity]

CSIStorageCapacityFilteringHandler is a specialization of cache.TypedFilteringResourceEventHandler for CSIStorageCapacity.

type CSIStorageCapacityHandlerFuncs added in v0.37.0

type CSIStorageCapacityHandlerFuncs = cache.TypedResourceEventHandlerFuncs[*apistoragev1.CSIStorageCapacity]

CSIStorageCapacityHandlerFuncs is a specialization of cache.TypedResourceEventHandlerFuncs for CSIStorageCapacity.

type CSIStorageCapacityIndexInformer added in v0.37.0

type CSIStorageCapacityIndexInformer cache.TypedSharedIndexInformer[*apistoragev1.CSIStorageCapacity]

CSIStorageCapacityIndexInformer is a wrapper around the underlying cache.SharedIndexInformer with type-safe variants of several methods.

func NewTypedCSIStorageCapacityInformer added in v0.37.0

func NewTypedCSIStorageCapacityInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers CSIStorageCapacityIndexers) CSIStorageCapacityIndexInformer

NewTypedCSIStorageCapacityInformer constructs a new informer for CSIStorageCapacity type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedCSIStorageCapacityInformerWithOptions added in v0.37.0

func NewTypedCSIStorageCapacityInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) CSIStorageCapacityIndexInformer

NewTypedCSIStorageCapacityInformerWithOptions constructs a new informer for CSIStorageCapacity type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedFilteredCSIStorageCapacityInformer added in v0.37.0

func NewTypedFilteredCSIStorageCapacityInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers CSIStorageCapacityIndexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) CSIStorageCapacityIndexInformer

NewTypedFilteredCSIStorageCapacityInformer constructs a new informer for CSIStorageCapacity type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func ToCSIStorageCapacityIndexInformer added in v0.37.0

func ToCSIStorageCapacityIndexInformer(informer cache.SharedIndexInformer) CSIStorageCapacityIndexInformer

ToCSIStorageCapacityIndexInformer converts an untyped informer into a CSIStorageCapacityIndexInformer.

WARNING: this conversion is only safe if the informer handles objects of type *CSIStorageCapacity. If that is not the case, calling type-safe methods of the returned CSIStorageCapacityIndexInformer leads to runtime panics. A safer alternative is to pass around a CSIStorageCapacityIndexInformer instances that was obtained from a SharedInformerFactory.

type CSIStorageCapacityIndexers added in v0.37.0

type CSIStorageCapacityIndexers = cache.TypedIndexers[*apistoragev1.CSIStorageCapacity]

CSIStorageCapacityIndexers is a specialization of cache.TypedIndexers for CSIStorageCapacity.

type CSIStorageCapacityInformer added in v0.24.0

type CSIStorageCapacityInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() storagev1.CSIStorageCapacityLister
}

CSIStorageCapacityInformer provides access to a shared informer and lister for CSIStorageCapacities. Prefer using the type-safe variant (see TypedCSIStorageCapacityInformer).

type DeletedCSIDriver added in v0.37.0

type DeletedCSIDriver = cache.DeletedObject[*apistoragev1.CSIDriver]

DeletedCSIDriver is a specialization of cache.DeletedObject for CSIDriver.

type DeletedCSINode added in v0.37.0

type DeletedCSINode = cache.DeletedObject[*apistoragev1.CSINode]

DeletedCSINode is a specialization of cache.DeletedObject for CSINode.

type DeletedCSIStorageCapacity added in v0.37.0

type DeletedCSIStorageCapacity = cache.DeletedObject[*apistoragev1.CSIStorageCapacity]

DeletedCSIStorageCapacity is a specialization of cache.DeletedObject for CSIStorageCapacity.

type DeletedStorageClass added in v0.37.0

type DeletedStorageClass = cache.DeletedObject[*apistoragev1.StorageClass]

DeletedStorageClass is a specialization of cache.DeletedObject for StorageClass.

type DeletedVolumeAttachment added in v0.37.0

type DeletedVolumeAttachment = cache.DeletedObject[*apistoragev1.VolumeAttachment]

DeletedVolumeAttachment is a specialization of cache.DeletedObject for VolumeAttachment.

type DeletedVolumeAttributesClass added in v0.37.0

type DeletedVolumeAttributesClass = cache.DeletedObject[*apistoragev1.VolumeAttributesClass]

DeletedVolumeAttributesClass is a specialization of cache.DeletedObject for VolumeAttributesClass.

type Interface

type Interface interface {
	// CSIDrivers returns a CSIDriverInformer.
	CSIDrivers() TypedCSIDriverInformer
	// CSINodes returns a CSINodeInformer.
	CSINodes() TypedCSINodeInformer
	// CSIStorageCapacities returns a CSIStorageCapacityInformer.
	CSIStorageCapacities() TypedCSIStorageCapacityInformer
	// StorageClasses returns a StorageClassInformer.
	StorageClasses() TypedStorageClassInformer
	// VolumeAttachments returns a VolumeAttachmentInformer.
	VolumeAttachments() TypedVolumeAttachmentInformer
	// VolumeAttributesClasses returns a VolumeAttributesClassInformer.
	VolumeAttributesClasses() TypedVolumeAttributesClassInformer
}

Interface provides access to all the informers in this group version.

func New

New returns a new Interface.

type StorageClassDetailedHandlerFuncs added in v0.37.0

type StorageClassDetailedHandlerFuncs = cache.TypedResourceEventHandlerDetailedFuncs[*apistoragev1.StorageClass]

StorageClassDetailedHandlerFuncs is a specialization of cache.TypedResourceEventHandlerDetailedFuncs for StorageClass.

type StorageClassFilteringHandler added in v0.37.0

type StorageClassFilteringHandler = cache.TypedFilteringResourceEventHandler[*apistoragev1.StorageClass]

StorageClassFilteringHandler is a specialization of cache.TypedFilteringResourceEventHandler for StorageClass.

type StorageClassHandlerFuncs added in v0.37.0

StorageClassHandlerFuncs is a specialization of cache.TypedResourceEventHandlerFuncs for StorageClass.

type StorageClassIndexInformer added in v0.37.0

type StorageClassIndexInformer cache.TypedSharedIndexInformer[*apistoragev1.StorageClass]

StorageClassIndexInformer is a wrapper around the underlying cache.SharedIndexInformer with type-safe variants of several methods.

func NewTypedFilteredStorageClassInformer added in v0.37.0

func NewTypedFilteredStorageClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers StorageClassIndexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) StorageClassIndexInformer

NewTypedFilteredStorageClassInformer constructs a new informer for StorageClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedStorageClassInformer added in v0.37.0

func NewTypedStorageClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers StorageClassIndexers) StorageClassIndexInformer

NewTypedStorageClassInformer constructs a new informer for StorageClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedStorageClassInformerWithOptions added in v0.37.0

func NewTypedStorageClassInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) StorageClassIndexInformer

NewTypedStorageClassInformerWithOptions constructs a new informer for StorageClass type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func ToStorageClassIndexInformer added in v0.37.0

func ToStorageClassIndexInformer(informer cache.SharedIndexInformer) StorageClassIndexInformer

ToStorageClassIndexInformer converts an untyped informer into a StorageClassIndexInformer.

WARNING: this conversion is only safe if the informer handles objects of type *StorageClass. If that is not the case, calling type-safe methods of the returned StorageClassIndexInformer leads to runtime panics. A safer alternative is to pass around a StorageClassIndexInformer instances that was obtained from a SharedInformerFactory.

type StorageClassIndexers added in v0.37.0

type StorageClassIndexers = cache.TypedIndexers[*apistoragev1.StorageClass]

StorageClassIndexers is a specialization of cache.TypedIndexers for StorageClass.

type StorageClassInformer

type StorageClassInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() storagev1.StorageClassLister
}

StorageClassInformer provides access to a shared informer and lister for StorageClasses. Prefer using the type-safe variant (see TypedStorageClassInformer).

type TypedCSIDriverInformer added in v0.37.0

type TypedCSIDriverInformer interface {
	Informer() cache.SharedIndexInformer
	TypedInformer() CSIDriverIndexInformer
	Lister() storagev1.CSIDriverLister
}

TypedCSIDriverInformer provides access to a shared informer and lister for CSIDrivers, including the type-safe TypedInformer variant. It is a superset of CSIDriverInformer.

func ToTypedCSIDriverInformer added in v0.37.0

func ToTypedCSIDriverInformer(informer CSIDriverInformer) TypedCSIDriverInformer

ToTypedCSIDriverInformer converts an untyped informer into a TypedCSIDriverInformer.

WARNING: this conversion is only safe if the informer handles objects of type *CSIDriver. If that is not the case, calling type-safe methods of the returned TypedCSIDriverInformer leads to runtime panics. A safer alternative is to pass around a TypedCSIDriverInformer instances that was obtained from a SharedInformerFactory.

type TypedCSINodeInformer added in v0.37.0

type TypedCSINodeInformer interface {
	Informer() cache.SharedIndexInformer
	TypedInformer() CSINodeIndexInformer
	Lister() storagev1.CSINodeLister
}

TypedCSINodeInformer provides access to a shared informer and lister for CSINodes, including the type-safe TypedInformer variant. It is a superset of CSINodeInformer.

func ToTypedCSINodeInformer added in v0.37.0

func ToTypedCSINodeInformer(informer CSINodeInformer) TypedCSINodeInformer

ToTypedCSINodeInformer converts an untyped informer into a TypedCSINodeInformer.

WARNING: this conversion is only safe if the informer handles objects of type *CSINode. If that is not the case, calling type-safe methods of the returned TypedCSINodeInformer leads to runtime panics. A safer alternative is to pass around a TypedCSINodeInformer instances that was obtained from a SharedInformerFactory.

type TypedCSIStorageCapacityInformer added in v0.37.0

type TypedCSIStorageCapacityInformer interface {
	Informer() cache.SharedIndexInformer
	TypedInformer() CSIStorageCapacityIndexInformer
	Lister() storagev1.CSIStorageCapacityLister
}

TypedCSIStorageCapacityInformer provides access to a shared informer and lister for CSIStorageCapacities, including the type-safe TypedInformer variant. It is a superset of CSIStorageCapacityInformer.

func ToTypedCSIStorageCapacityInformer added in v0.37.0

func ToTypedCSIStorageCapacityInformer(informer CSIStorageCapacityInformer) TypedCSIStorageCapacityInformer

ToTypedCSIStorageCapacityInformer converts an untyped informer into a TypedCSIStorageCapacityInformer.

WARNING: this conversion is only safe if the informer handles objects of type *CSIStorageCapacity. If that is not the case, calling type-safe methods of the returned TypedCSIStorageCapacityInformer leads to runtime panics. A safer alternative is to pass around a TypedCSIStorageCapacityInformer instances that was obtained from a SharedInformerFactory.

type TypedStorageClassInformer added in v0.37.0

type TypedStorageClassInformer interface {
	Informer() cache.SharedIndexInformer
	TypedInformer() StorageClassIndexInformer
	Lister() storagev1.StorageClassLister
}

TypedStorageClassInformer provides access to a shared informer and lister for StorageClasses, including the type-safe TypedInformer variant. It is a superset of StorageClassInformer.

func ToTypedStorageClassInformer added in v0.37.0

func ToTypedStorageClassInformer(informer StorageClassInformer) TypedStorageClassInformer

ToTypedStorageClassInformer converts an untyped informer into a TypedStorageClassInformer.

WARNING: this conversion is only safe if the informer handles objects of type *StorageClass. If that is not the case, calling type-safe methods of the returned TypedStorageClassInformer leads to runtime panics. A safer alternative is to pass around a TypedStorageClassInformer instances that was obtained from a SharedInformerFactory.

type TypedVolumeAttachmentInformer added in v0.37.0

type TypedVolumeAttachmentInformer interface {
	Informer() cache.SharedIndexInformer
	TypedInformer() VolumeAttachmentIndexInformer
	Lister() storagev1.VolumeAttachmentLister
}

TypedVolumeAttachmentInformer provides access to a shared informer and lister for VolumeAttachments, including the type-safe TypedInformer variant. It is a superset of VolumeAttachmentInformer.

func ToTypedVolumeAttachmentInformer added in v0.37.0

func ToTypedVolumeAttachmentInformer(informer VolumeAttachmentInformer) TypedVolumeAttachmentInformer

ToTypedVolumeAttachmentInformer converts an untyped informer into a TypedVolumeAttachmentInformer.

WARNING: this conversion is only safe if the informer handles objects of type *VolumeAttachment. If that is not the case, calling type-safe methods of the returned TypedVolumeAttachmentInformer leads to runtime panics. A safer alternative is to pass around a TypedVolumeAttachmentInformer instances that was obtained from a SharedInformerFactory.

type TypedVolumeAttributesClassInformer added in v0.37.0

type TypedVolumeAttributesClassInformer interface {
	Informer() cache.SharedIndexInformer
	TypedInformer() VolumeAttributesClassIndexInformer
	Lister() storagev1.VolumeAttributesClassLister
}

TypedVolumeAttributesClassInformer provides access to a shared informer and lister for VolumeAttributesClasses, including the type-safe TypedInformer variant. It is a superset of VolumeAttributesClassInformer.

func ToTypedVolumeAttributesClassInformer added in v0.37.0

func ToTypedVolumeAttributesClassInformer(informer VolumeAttributesClassInformer) TypedVolumeAttributesClassInformer

ToTypedVolumeAttributesClassInformer converts an untyped informer into a TypedVolumeAttributesClassInformer.

WARNING: this conversion is only safe if the informer handles objects of type *VolumeAttributesClass. If that is not the case, calling type-safe methods of the returned TypedVolumeAttributesClassInformer leads to runtime panics. A safer alternative is to pass around a TypedVolumeAttributesClassInformer instances that was obtained from a SharedInformerFactory.

type VolumeAttachmentDetailedHandlerFuncs added in v0.37.0

type VolumeAttachmentDetailedHandlerFuncs = cache.TypedResourceEventHandlerDetailedFuncs[*apistoragev1.VolumeAttachment]

VolumeAttachmentDetailedHandlerFuncs is a specialization of cache.TypedResourceEventHandlerDetailedFuncs for VolumeAttachment.

type VolumeAttachmentFilteringHandler added in v0.37.0

type VolumeAttachmentFilteringHandler = cache.TypedFilteringResourceEventHandler[*apistoragev1.VolumeAttachment]

VolumeAttachmentFilteringHandler is a specialization of cache.TypedFilteringResourceEventHandler for VolumeAttachment.

type VolumeAttachmentHandlerFuncs added in v0.37.0

type VolumeAttachmentHandlerFuncs = cache.TypedResourceEventHandlerFuncs[*apistoragev1.VolumeAttachment]

VolumeAttachmentHandlerFuncs is a specialization of cache.TypedResourceEventHandlerFuncs for VolumeAttachment.

type VolumeAttachmentIndexInformer added in v0.37.0

type VolumeAttachmentIndexInformer cache.TypedSharedIndexInformer[*apistoragev1.VolumeAttachment]

VolumeAttachmentIndexInformer is a wrapper around the underlying cache.SharedIndexInformer with type-safe variants of several methods.

func NewTypedFilteredVolumeAttachmentInformer added in v0.37.0

func NewTypedFilteredVolumeAttachmentInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers VolumeAttachmentIndexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) VolumeAttachmentIndexInformer

NewTypedFilteredVolumeAttachmentInformer constructs a new informer for VolumeAttachment type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedVolumeAttachmentInformer added in v0.37.0

func NewTypedVolumeAttachmentInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers VolumeAttachmentIndexers) VolumeAttachmentIndexInformer

NewTypedVolumeAttachmentInformer constructs a new informer for VolumeAttachment type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedVolumeAttachmentInformerWithOptions added in v0.37.0

func NewTypedVolumeAttachmentInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) VolumeAttachmentIndexInformer

NewTypedVolumeAttachmentInformerWithOptions constructs a new informer for VolumeAttachment type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func ToVolumeAttachmentIndexInformer added in v0.37.0

func ToVolumeAttachmentIndexInformer(informer cache.SharedIndexInformer) VolumeAttachmentIndexInformer

ToVolumeAttachmentIndexInformer converts an untyped informer into a VolumeAttachmentIndexInformer.

WARNING: this conversion is only safe if the informer handles objects of type *VolumeAttachment. If that is not the case, calling type-safe methods of the returned VolumeAttachmentIndexInformer leads to runtime panics. A safer alternative is to pass around a VolumeAttachmentIndexInformer instances that was obtained from a SharedInformerFactory.

type VolumeAttachmentIndexers added in v0.37.0

type VolumeAttachmentIndexers = cache.TypedIndexers[*apistoragev1.VolumeAttachment]

VolumeAttachmentIndexers is a specialization of cache.TypedIndexers for VolumeAttachment.

type VolumeAttachmentInformer

type VolumeAttachmentInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() storagev1.VolumeAttachmentLister
}

VolumeAttachmentInformer provides access to a shared informer and lister for VolumeAttachments. Prefer using the type-safe variant (see TypedVolumeAttachmentInformer).

type VolumeAttributesClassDetailedHandlerFuncs added in v0.37.0

type VolumeAttributesClassDetailedHandlerFuncs = cache.TypedResourceEventHandlerDetailedFuncs[*apistoragev1.VolumeAttributesClass]

VolumeAttributesClassDetailedHandlerFuncs is a specialization of cache.TypedResourceEventHandlerDetailedFuncs for VolumeAttributesClass.

type VolumeAttributesClassFilteringHandler added in v0.37.0

type VolumeAttributesClassFilteringHandler = cache.TypedFilteringResourceEventHandler[*apistoragev1.VolumeAttributesClass]

VolumeAttributesClassFilteringHandler is a specialization of cache.TypedFilteringResourceEventHandler for VolumeAttributesClass.

type VolumeAttributesClassHandlerFuncs added in v0.37.0

type VolumeAttributesClassHandlerFuncs = cache.TypedResourceEventHandlerFuncs[*apistoragev1.VolumeAttributesClass]

VolumeAttributesClassHandlerFuncs is a specialization of cache.TypedResourceEventHandlerFuncs for VolumeAttributesClass.

type VolumeAttributesClassIndexInformer added in v0.37.0

type VolumeAttributesClassIndexInformer cache.TypedSharedIndexInformer[*apistoragev1.VolumeAttributesClass]

VolumeAttributesClassIndexInformer is a wrapper around the underlying cache.SharedIndexInformer with type-safe variants of several methods.

func NewTypedFilteredVolumeAttributesClassInformer added in v0.37.0

func NewTypedFilteredVolumeAttributesClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers VolumeAttributesClassIndexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) VolumeAttributesClassIndexInformer

NewTypedFilteredVolumeAttributesClassInformer constructs a new informer for VolumeAttributesClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedVolumeAttributesClassInformer added in v0.37.0

func NewTypedVolumeAttributesClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers VolumeAttributesClassIndexers) VolumeAttributesClassIndexInformer

NewTypedVolumeAttributesClassInformer constructs a new informer for VolumeAttributesClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewTypedVolumeAttributesClassInformerWithOptions added in v0.37.0

func NewTypedVolumeAttributesClassInformerWithOptions(client kubernetes.Interface, options internalinterfaces.InformerOptions) VolumeAttributesClassIndexInformer

NewTypedVolumeAttributesClassInformerWithOptions constructs a new informer for VolumeAttributesClass type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func ToVolumeAttributesClassIndexInformer added in v0.37.0

func ToVolumeAttributesClassIndexInformer(informer cache.SharedIndexInformer) VolumeAttributesClassIndexInformer

ToVolumeAttributesClassIndexInformer converts an untyped informer into a VolumeAttributesClassIndexInformer.

WARNING: this conversion is only safe if the informer handles objects of type *VolumeAttributesClass. If that is not the case, calling type-safe methods of the returned VolumeAttributesClassIndexInformer leads to runtime panics. A safer alternative is to pass around a VolumeAttributesClassIndexInformer instances that was obtained from a SharedInformerFactory.

type VolumeAttributesClassIndexers added in v0.37.0

type VolumeAttributesClassIndexers = cache.TypedIndexers[*apistoragev1.VolumeAttributesClass]

VolumeAttributesClassIndexers is a specialization of cache.TypedIndexers for VolumeAttributesClass.

type VolumeAttributesClassInformer added in v0.34.0

type VolumeAttributesClassInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() storagev1.VolumeAttributesClassLister
}

VolumeAttributesClassInformer provides access to a shared informer and lister for VolumeAttributesClasses. Prefer using the type-safe variant (see TypedVolumeAttributesClassInformer).

Jump to