package v1beta1
import "k8s.io/client-go/informers/storage/v1beta1"
Index ¶
- func NewCSIDriverInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
- func NewCSINodeInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
- func NewCSIStorageCapacityInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
- func NewFilteredCSIDriverInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
- func NewFilteredCSINodeInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
- func NewFilteredCSIStorageCapacityInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
- func NewFilteredStorageClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
- func NewFilteredVolumeAttachmentInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
- func NewFilteredVolumeAttributesClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
- func NewStorageClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
- func NewVolumeAttachmentInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
- func NewVolumeAttributesClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
- type CSIDriverInformer
- type CSINodeInformer
- type CSIStorageCapacityInformer
- type Interface
- type StorageClassInformer
- type VolumeAttachmentInformer
- type VolumeAttributesClassInformer
Functions ¶
func NewCSIDriverInformer ¶
func NewCSIDriverInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewCSIDriverInformer constructs a new informer for CSIDriver type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewCSINodeInformer ¶
func NewCSINodeInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewCSINodeInformer constructs a new informer for CSINode type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewCSIStorageCapacityInformer ¶
func NewCSIStorageCapacityInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewCSIStorageCapacityInformer constructs a new informer for CSIStorageCapacity type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredCSIDriverInformer ¶
func NewFilteredCSIDriverInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredCSIDriverInformer constructs a new informer for CSIDriver type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredCSINodeInformer ¶
func NewFilteredCSINodeInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredCSINodeInformer constructs a new informer for CSINode type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredCSIStorageCapacityInformer ¶
func NewFilteredCSIStorageCapacityInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredCSIStorageCapacityInformer constructs a new informer for CSIStorageCapacity type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredStorageClassInformer ¶
func NewFilteredStorageClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredStorageClassInformer constructs a new informer for StorageClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredVolumeAttachmentInformer ¶
func NewFilteredVolumeAttachmentInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredVolumeAttachmentInformer constructs a new informer for VolumeAttachment type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredVolumeAttributesClassInformer ¶
func NewFilteredVolumeAttributesClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredVolumeAttributesClassInformer constructs a new informer for VolumeAttributesClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewStorageClassInformer ¶
func NewStorageClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewStorageClassInformer constructs a new informer for StorageClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewVolumeAttachmentInformer ¶
func NewVolumeAttachmentInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewVolumeAttachmentInformer constructs a new informer for VolumeAttachment type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewVolumeAttributesClassInformer ¶
func NewVolumeAttributesClassInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewVolumeAttributesClassInformer constructs a new informer for VolumeAttributesClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type CSIDriverInformer ¶
type CSIDriverInformer interface {
Informer() cache.SharedIndexInformer
Lister() storagev1beta1.CSIDriverLister
}
CSIDriverInformer provides access to a shared informer and lister for CSIDrivers.
type CSINodeInformer ¶
type CSINodeInformer interface {
Informer() cache.SharedIndexInformer
Lister() storagev1beta1.CSINodeLister
}
CSINodeInformer provides access to a shared informer and lister for CSINodes.
type CSIStorageCapacityInformer ¶
type CSIStorageCapacityInformer interface {
Informer() cache.SharedIndexInformer
Lister() storagev1beta1.CSIStorageCapacityLister
}
CSIStorageCapacityInformer provides access to a shared informer and lister for CSIStorageCapacities.
type Interface ¶
type Interface interface {
// CSIDrivers returns a CSIDriverInformer.
CSIDrivers() CSIDriverInformer
// CSINodes returns a CSINodeInformer.
CSINodes() CSINodeInformer
// CSIStorageCapacities returns a CSIStorageCapacityInformer.
CSIStorageCapacities() CSIStorageCapacityInformer
// StorageClasses returns a StorageClassInformer.
StorageClasses() StorageClassInformer
// VolumeAttachments returns a VolumeAttachmentInformer.
VolumeAttachments() VolumeAttachmentInformer
// VolumeAttributesClasses returns a VolumeAttributesClassInformer.
VolumeAttributesClasses() VolumeAttributesClassInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type StorageClassInformer ¶
type StorageClassInformer interface {
Informer() cache.SharedIndexInformer
Lister() storagev1beta1.StorageClassLister
}
StorageClassInformer provides access to a shared informer and lister for StorageClasses.
type VolumeAttachmentInformer ¶
type VolumeAttachmentInformer interface {
Informer() cache.SharedIndexInformer
Lister() storagev1beta1.VolumeAttachmentLister
}
VolumeAttachmentInformer provides access to a shared informer and lister for VolumeAttachments.
type VolumeAttributesClassInformer ¶
type VolumeAttributesClassInformer interface {
Informer() cache.SharedIndexInformer
Lister() storagev1beta1.VolumeAttributesClassLister
}
VolumeAttributesClassInformer provides access to a shared informer and lister for VolumeAttributesClasses.
Source Files ¶
csidriver.go csinode.go csistoragecapacity.go interface.go storageclass.go volumeattachment.go volumeattributesclass.go
- Version
- v0.33.8
- Published
- Feb 10, 2026
- Platform
- linux/amd64
- Imports
- 10 packages
- Last checked
- 1 hour ago –
Tools for package owners.