package v1alpha1

import "k8s.io/client-go/informers/certificates/v1alpha1"

Index

Functions

func NewClusterTrustBundleInformer

func NewClusterTrustBundleInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewClusterTrustBundleInformer constructs a new informer for ClusterTrustBundle type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredClusterTrustBundleInformer

func NewFilteredClusterTrustBundleInformer(client kubernetes.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredClusterTrustBundleInformer constructs a new informer for ClusterTrustBundle type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewFilteredPodCertificateRequestInformer

func NewFilteredPodCertificateRequestInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer

NewFilteredPodCertificateRequestInformer constructs a new informer for PodCertificateRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

func NewPodCertificateRequestInformer

func NewPodCertificateRequestInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer

NewPodCertificateRequestInformer constructs a new informer for PodCertificateRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.

Types

type ClusterTrustBundleInformer

type ClusterTrustBundleInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() certificatesv1alpha1.ClusterTrustBundleLister
}

ClusterTrustBundleInformer provides access to a shared informer and lister for ClusterTrustBundles.

type Interface

type Interface interface {
	// ClusterTrustBundles returns a ClusterTrustBundleInformer.
	ClusterTrustBundles() ClusterTrustBundleInformer
	// PodCertificateRequests returns a PodCertificateRequestInformer.
	PodCertificateRequests() PodCertificateRequestInformer
}

Interface provides access to all the informers in this group version.

func New

New returns a new Interface.

type PodCertificateRequestInformer

type PodCertificateRequestInformer interface {
	Informer() cache.SharedIndexInformer
	Lister() certificatesv1alpha1.PodCertificateRequestLister
}

PodCertificateRequestInformer provides access to a shared informer and lister for PodCertificateRequests.

Source Files

clustertrustbundle.go interface.go podcertificaterequest.go

Version
v0.34.4
Published
Feb 10, 2026
Platform
linux/amd64
Imports
10 packages
Last checked
18 seconds ago

Tools for package owners.