package v1alpha2
import "k8s.io/client-go/informers/scheduling/v1alpha2"
Index ¶
- func NewFilteredPodGroupInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
- func NewFilteredWorkloadInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
- func NewPodGroupInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
- func NewPodGroupInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) cache.SharedIndexInformer
- func NewWorkloadInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
- func NewWorkloadInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) cache.SharedIndexInformer
- type Interface
- type PodGroupInformer
- type WorkloadInformer
Functions ¶
func NewFilteredPodGroupInformer ¶
func NewFilteredPodGroupInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredPodGroupInformer constructs a new informer for PodGroup type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredWorkloadInformer ¶
func NewFilteredWorkloadInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredWorkloadInformer constructs a new informer for Workload type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewPodGroupInformer ¶
func NewPodGroupInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewPodGroupInformer constructs a new informer for PodGroup type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewPodGroupInformerWithOptions ¶
func NewPodGroupInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) cache.SharedIndexInformer
NewPodGroupInformerWithOptions constructs a new informer for PodGroup type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewWorkloadInformer ¶
func NewWorkloadInformer(client kubernetes.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewWorkloadInformer constructs a new informer for Workload type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewWorkloadInformerWithOptions ¶
func NewWorkloadInformerWithOptions(client kubernetes.Interface, namespace string, options internalinterfaces.InformerOptions) cache.SharedIndexInformer
NewWorkloadInformerWithOptions constructs a new informer for Workload type with additional options. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type Interface ¶
type Interface interface {
// PodGroups returns a PodGroupInformer.
PodGroups() PodGroupInformer
// Workloads returns a WorkloadInformer.
Workloads() WorkloadInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type PodGroupInformer ¶
type PodGroupInformer interface {
Informer() cache.SharedIndexInformer
Lister() schedulingv1alpha2.PodGroupLister
}
PodGroupInformer provides access to a shared informer and lister for PodGroups.
type WorkloadInformer ¶
type WorkloadInformer interface {
Informer() cache.SharedIndexInformer
Lister() schedulingv1alpha2.WorkloadLister
}
WorkloadInformer provides access to a shared informer and lister for Workloads.
Source Files ¶
interface.go podgroup.go workload.go
- Version
- v0.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Imports
- 11 packages
- Last checked
- 6 days ago –
Tools for package owners.